"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.camelCase = camelCase;
exports.formatCss = formatCss;
exports.addPrefixCss = addPrefixCss;
exports.isEmpty = isEmpty;

function camelCase(str) {
  return str.replace(/-([a-z])/g, ($0, $1) => $1.toUpperCase()).replace("-", "");
}
/**
 * Format the css property object
 * @param  {Object} props Attribute object
 * @return {Object}       Prefixed formatting attribute object
 */


function formatCss(props) {
  const prefixs = ["-webkit-", "-moz-", "-ms-"];
  const result = {};
  const regPrefix = /transform|transition/;

  for (const key in props) {
    if (Object.prototype.hasOwnProperty.call(props, key)) {
      const styleValue = props[key]; // If the detection is the transform or transition attribute

      if (regPrefix.test(key)) {
        for (let i = 0; i < prefixs.length; i++) {
          const styleName = camelCase(prefixs[i] + key);
          result[styleName] = styleValue.replace(regPrefix, "".concat(prefixs[i], "$&"));
        }
      }

      result[key] = styleValue;
    }
  }

  return result;
}
/**
 * Add css styles to elements
 * @param {Object} element Target element
 * @param {Object} props   css attribute object
 */


function addPrefixCss(element, props) {
  const formatedProps = formatCss(props);

  for (const key in formatedProps) {
    if (Object.prototype.hasOwnProperty.call(formatedProps, key)) {
      element.style[key] = formatedProps[key];
    }
  }
}

function isEmpty(obj) {
  return Object.keys(obj).length === 0;
}
//# sourceMappingURL=prefix.js.map