"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.shallowEqual = shallowEqual;
exports.default = void 0;

function shallowEqual(prev, next) {
  if (prev === next) return true;
  const prevKeys = Object.keys(prev);
  const nextKeys = Object.keys(next);
  if (prevKeys.length !== nextKeys.length) return false;
  return prevKeys.every(key => {
    return Object.prototype.hasOwnProperty.call(prev, key) && prev[key] === next[key];
  });
}

function PureRender(Component) {
  Component.prototype.shouldComponentUpdate = function (nextProps, nextState) {
    return PureRender.shouldComponentUpdate(nextProps, nextState, this.props, this.state);
  };
}

PureRender.shouldComponentUpdate = function (nextProps, nextState, preProps, preState) {
  return !shallowEqual(preProps, nextProps) || !shallowEqual(preState, nextState);
};

var _default = PureRender;
exports.default = _default;
//# sourceMappingURL=pureRender.js.map